.. include:: ../README.rst
  :end-before: See the `complete documentation`__

.. toctree::
  :caption: Getting started
  :hidden:

  basic_usage
  advanced_usage
  getting_help

.. toctree::
  :caption: Examples
  :hidden:

  examples/collections
  examples/pathlib
  examples/other_projects

.. toctree::
  :caption: Syntax Reference
  :hidden:

  syntax/rst
  syntax/sphinx
  syntax/python

